# Changelog

## [0.5.0](https://github.com/tkk2112/cmakepresets/compare/v0.4.1...v0.5.0) (2025-10-25)


### ⚠ BREAKING CHANGES

* fixes instability in the testsuite on certain platforms

### Bug Fixes

* fixes instability in the testsuite on certain platforms ([791a0b9](https://github.com/tkk2112/cmakepresets/commit/791a0b90e8d303770468cbece1212a63e42ee2d7))

## [0.4.1](https://github.com/tkk2112/cmakepresets/compare/v0.4.0...v0.4.1) (2025-06-10)


### Bug Fixes

* **deps:** update dependency requests to v2.32.4 [security] ([0df49b4](https://github.com/tkk2112/cmakepresets/commit/0df49b445788ca01613a11d453a3b2cb3a10dbc5))

## [0.4.0](https://github.com/tkk2112/cmakepresets/compare/v0.3.1...v0.4.0) (2025-03-26)


### ⚠ BREAKING CHANGES

* update doc and add it to tests for the api doctest examples

### Features

* add CMakeRoot ([f9979c6](https://github.com/tkk2112/cmakepresets/commit/f9979c6c3f1fae3c52e2f5b0a131de07bad7e3ec))
* add constants ([c13ead1](https://github.com/tkk2112/cmakepresets/commit/c13ead11c491df2196ee460cf8af0a3ea2f69432))
* add utils ([read|write]_file_text) ([de731e6](https://github.com/tkk2112/cmakepresets/commit/de731e6a5beee59e23eeb8d1e83b221753dbd706))
* improve pseudo macro resolver ([374dc5a](https://github.com/tkk2112/cmakepresets/commit/374dc5a27fb1d053c6be6a5f34c8477e0eb9920f))
* update CMakePresets_json to also be a context_manager ([1c3f4a6](https://github.com/tkk2112/cmakepresets/commit/1c3f4a64cdba06cbb9d82fa5677c3f005fbe98aa))
* update doc and add it to tests for the api doctest examples ([649d8f8](https://github.com/tkk2112/cmakepresets/commit/649d8f82d92608ba4c1d005e9759f9afdbbba93c))
* update to use CMakeRoot ++ ([2737dc1](https://github.com/tkk2112/cmakepresets/commit/2737dc19394009c9c7024ad8d093205ffe79cf9d))


### Bug Fixes

* change a couple of regular print to console.print ([09c0b70](https://github.com/tkk2112/cmakepresets/commit/09c0b709a4ee6f98ccf529b880db894e55177a48))

## [0.3.1](https://github.com/tkk2112/cmakepresets/compare/v0.3.0...v0.3.1) (2025-03-19)


### Features

* add --resolve to show command to resolve macros ([04b928d](https://github.com/tkk2112/cmakepresets/commit/04b928d515a1cf153894f92cb8540104778fc642))
* add pseudo macro resolver ([d7188d7](https://github.com/tkk2112/cmakepresets/commit/d7188d7e0ea892d31398fad362c48c28c75eb262))
* resolve macros of a preset with resolve_macro_values ([3fcb0fa](https://github.com/tkk2112/cmakepresets/commit/3fcb0faa56618964f2347fa42c34d5eb1c0b81c7))

## [0.3.0](https://github.com/tkk2112/cmakepresets/compare/v0.2.6...v0.3.0) (2025-03-19)


### ⚠ BREAKING CHANGES

* missing s on project script

### Bug Fixes

* missing s on project script ([94da3e4](https://github.com/tkk2112/cmakepresets/commit/94da3e4104850337d9cdaa0c07b60f1ebe5c595f))

## [0.2.6](https://github.com/tkk2112/cmakepresets/compare/v0.2.5...v0.2.6) (2025-03-18)


### Bug Fixes

* project version file was wrongly registered in config ([491c2c9](https://github.com/tkk2112/cmakepresets/commit/491c2c92df80996b0210ca7824dad60582f87e14))

## [0.2.5](https://github.com/tkk2112/cmakepresets/compare/v0.2.1...v0.2.5) (2025-03-18)


### Features

* add release-please to module ([fe61f58](https://github.com/tkk2112/cmakepresets/commit/fe61f58484a77cbb69bc639623b42be213033299))


### Bug Fixes

* prefix version and add to README.md ([47fcbc6](https://github.com/tkk2112/cmakepresets/commit/47fcbc6da10e8f23384c6b50c377197c3d04bf78))
